## ----load-data, results='hide',cache=TRUE--------------------------------
# Loading data for use in all examples

library(oro.nifti) #for opening nii.gz files

s_map1<-readNIfTI(system.file('seed_corr_1.nii.gz', package='ggBrain'))
s_map2<-readNIfTI(system.file('seed_corr_2.nii.gz', package='ggBrain'))
template <- readNIfTI(system.file('template.nii.gz', package='ggBrain'))
mask <- readNIfTI(system.file('brain_mask.nii.gz', package='ggBrain'))
seed_mask <- readNIfTI(system.file('seed_mask.nii.gz', package='ggBrain'))
nii1_trunc <- readNIfTI(system.file('subj_trunc_1.nii.gz', package='ggBrain'))


# get high definition brain image from the brainR package
if(require(brainR)){
  hd_template <- readNIfTI(system.file("MNI152_T1_1mm_brain.nii.gz", package="brainR"))
}

library(ggBrain) 
library(ggplot2) 


## ----single-plots-structural,cache=TRUE,fig.height=4,fig.width=4---------

dd<-ggBrain(brains=hd_template,mask=hd_template>0,mar=3,mar_ind=93,type='structural')
#now add aethetic changes with conventional ggplot code.
dd + scale_fill_continuous(low="black", high="white") + theme_black_bg()


## ----single-plots-seed-corr,cache=TRUE,fig.height=4,fig.width=4----------
# s_map1 is a seed correlation image, based on correlation with the region denoted by seed_mask
dd<-ggBrain(template=template,brains=s_map1,mask=mask,mar=3,mar_ind=30,type='signed')

dd + theme_black_bg()

## ----single-plots-abs-val,cache=TRUE,fig.height=4,fig.width=4------------
dd<-ggBrain(template=template,brains=abs(s_map1),mask=mask,mar=3,mar_ind=30,type='positive')

dd + scale_alpha(range=c(0,1)) + theme_black_bg()

## ---- single-plots-no-template,cache=TRUE,fig.height=4,fig.width=4-------
dd<-ggBrain(brains=abs(s_map1),mask=mask,mar=3,mar_ind=30,type='positive')

dd + scale_alpha(range=c(0,1)) + theme_black_bg()

## ----single-plots-bf,cache=TRUE,fig.height=4,fig.width=4-----------------
bf<-getBrainFrame(brains=hd_template,mar=3,mar_ind=93,mask=hd_template>0,center_coords=FALSE)
head(bf)

ggplot()+geom_tile(data=bf, aes(x=row,y=col,fill=value))+facet_grid(row_ind~col_ind)+coord_fixed(ratio = 1)

## ----4panel,cache=TRUE,fig.height=10,fig.width=5-------------------------
mar_ind<-floor(seq(140,90,length=4))

dd<-ggBrain(hd_template, mask=hd_template>0,
  mar= c(3,3,3,3),
	mar_ind=mar_ind,
	col_ind=c(1,1,1,1),
	row_ind=factor(c(1,2,3,4),labels=paste('Slice',mar_ind)),
	type='structural')

dd + theme_black_bg() 

## ----fMRI,cache=TRUE,fig.height=4,fig.width=8----------------------------
dd<-ggBrain(brains=nii1_trunc,template=template,
  mask=mask,
	mar=rep(3,4),
	mar_ind=rep(30,4),
	row_ind=rep(1,4),
	col_ind=paste('Time',1:4),
	time=1:4)

dd + theme_black_bg() + labs(title='Sample fMRI data')

## ----2brain_compare,cache=TRUE, fig.height=6,fig.width=8-----------------
dd<-ggBrain(brains=list(s_map1,s_map2),
  brain_ind=c(1,1,1,2,2,2),
	template=template,
	mar=c(1,2,3,1,2,3),
	mar_ind=c(37,18,30,37,18,30),
	row_ind=c('Subject 1','Subject 1','Subject 1','Subject 2','Subject 2','Subject 2'),
	col_ind=factor(c(1,2,3,1,2,3),labels=c('Sagittal','Coronal','Transverse')),
	mask=mask)
dd + ggtitle('Seed correlations for two subjects') + theme_black_bg()

## ----line-key-str,cache=TRUE,fig.height=9,fig.width=7--------------------
mar=c(3,3,3,3,3,3,3,1)
mar_ind=c(floor(seq(140,50,length=7)),88)
col_ind=c(1,1,1,1,2,2,2,2)
row_ind=c(1,2,3,4,1,2,3,4)
lines_mat<-cbind('panel'=8,mar,mar_ind)[1:7,]

lines_mat

dd <- ggBrain(brains=hd_template, mar=mar, mar_ind=mar_ind,
              row_ind=row_ind, col_ind=col_ind, mask=hd_template>0,
              type='structural', lines_mat=lines_mat)

dd + theme_black_bg() + theme_all_blank()

## ----line-key-corr,cache=TRUE,fig.height=9,fig.width=7-------------------
mar_ind=c(floor(seq(48,20,length=7)),30) #reduce dimensions
# to match fMRI data
lines_mat<-cbind('panel'=8,mar,mar_ind)[1:7,]

dd <- ggBrain(brains=s_map1, template=template, mar=mar,mar_ind=mar_ind,
              row_ind=row_ind, col_ind=col_ind, mask=mask, lines_mat=lines_mat)

dd + theme_black_bg() + theme_all_blank()

## ----tri-panel1,cache=TRUE,fig.height=5,fig.width=10---------------------
dd<-ggBrain(brains=s_map1,template=template,
  mar =		c(1,2,3),
	mar_ind =	c(37,18,30),
	row_ind=	c(1,1,2),
	col_ind=	c(2,1,1),
	tri_planar=TRUE, lines_color='black',mask=mask)
dd

## ----tri-panel2, results='hide',cache=TRUE,fig.height=6,fig.width=8------
mar   =   c(1,2,3)
col_ind = factor(c(1,2,3),labels=c('Sagittal','Coronal','Transverse'))
row_ind = c(1,1,1)
mar_ind=  c(37,18,30)

dd_mask<-ggBrain(brains=seed_mask,template=template,mar=mar,mar_ind=mar_ind,row_ind=row_ind,col_ind=col_ind,type='binary',binary_color='black',tri_planar=TRUE,mask=mask)+
	labs(alpha='Binary mask',title='Seed Mask')+theme_black_bg()


dd_1<-ggBrain(brains=s_map1,template=template,mar=mar,mar_ind=mar_ind,row_ind=row_ind,col_ind=col_ind,tri_planar=TRUE,mask=mask)+
	labs(title='Seed Correlation Map') + theme_black_bg()

library(gridExtra)
grid.arrange(dd_mask,dd_1)


